# Changelog

## [2.1.0] - 2022-08-23
### Added
+ Add python3.10 supporting
### Fixed
+ Fix EorzeaWeather.forecast timestamp type issue.
+ Fix EorzeaTime.weather_period timestamp type issue.
+ Fix type hint.
### Removed
+ Discard python3.6 supporting
+ Discard python3.7 supporting

## [2.0.0] - 2022-05-30
### Added
+ EorzeaPlaceName

## [1.5.2] - 2022-05-08
### Added
+ 6.1 weather data

## [1.5.1] - 2021-12-04
### Removed
+ Remove python 3.10 support

## [1.5.0] - 2021-12-04
### Added
+ 6.0 weather data

## [1.4.6] - 2021-05-05
### Added
+ 5.5 weather data

## [1.4.5] - 2021-01-15
### Added
+ 5.4 weather data

## [1.4.4] - 2020-10-22
### Added
+ EorzeaLang
+ EorzeaWeather.forecast with overload

## [1.4.3] - 2020-10-20
### Added
+ 5.35 weather data

## [1.4.1] - 2019-06-29

### Added
+ 5.1 weather data

## [1.4.0] - 2019-06-29

### Added
+ 5.0 weather data

### Deleted
+ `EorzeaWeather.forecast_weather()`

## [1.3.0] - 2019-06-25

### Added
+ forecast in EorzeaWeather

### Changed
+ rewrite docstring

### Deprecated
+ forecast_weather in EorzeaWeather is deprecated

